<?xml version="1.0"?>
<app>

<category>
Kernels
</category>

<name>
Liquorix 64 bit (ahs updates package)
</name>

<description>
<am>የ Liquorix ahs ማሻሻያ ጥቅል፣ ለራስ-ሰር ዝማኔዎች አህስ መንቃት ያስፈልገዋል</am>
<ar>ﺔﻴﺋﺎﻘﻠﺘﻟﺍ ﺕﺎﺜﻳﺪﺤﺘﻠﻟ ahs ﻦﻴﻜﻤﺗ Liquorix ahs ﺕﺎﺜﻳﺪﺤﺗ ﺔﻣﺰﺣ ﺐﻠﻄﺘﺗ</ar>
<bg>Пакет за актуализации на Liquorix ahs, изисква ahs да бъде активиран за автоматични актуализации</bg>
<bn>Liquorix ahs আপডেট প্যাকেজ, স্বয়ংক্রিয় আপডেটের জন্য ahs সক্ষম করা প্রয়োজন</bn>
<ca>Paquet d'actualitzacions de Liquorix ahs, requereix que ahs estigui habilitat per a actualitzacions automàtiques</ca>
<cs>Balíček aktualizací Liquorix ahs vyžaduje, aby byl ahs povolen pro automatické aktualizace</cs>
<da>Liquorix ahs opdateringspakke, kræver at ahs er aktiveret for automatiske opdateringer</da>
<de>Liquorix ahs-Aktualisierungspaket erfordert die Aktivierung von ahs für automatische Updates</de>
<el>Το πακέτο ενημερώσεων Liquorix ahs, απαιτεί το ahs να είναι ενεργοποιημένο για αυτόματες ενημερώσεις</el>
<es>Paquete de actualizaciones de Liquorix ahs, requiere que ahs esté habilitado para actualizaciones automáticas</es>
<et>Liquorixi ahsi värskenduspakett, automaatsete värskenduste jaoks peab ahs olema lubatud</et>
<eu>Liquorix ahs eguneratze paketea, eguneratze automatikoetarako ahs gaituta egotea eskatzen du</eu>
<en>Liquorix ahs updates package, requires ahs be enabled for automatic updates</en>
<fa>ﺩﺭﺍﺩ ﺭﺎﮐﺩﻮﺧ ﯽﻧﺎﺳﺭ ﺯﻭﺭ ﻪﺑ ﯼﺍﺮﺑ ahs ﻥﺩﺮﮐ ﻝﺎﻌﻓ ﻪﺑ ﺯﺎﯿﻧ ،Liquorix ahs ﯽﻧﺎﺳﺭ ﺯﻭﺭ ﻪﺑ ﻪﺘﺴﺑ</fa>
<fil_PH>Ang pakete ng mga update ng Liquorix ahs, ay nangangailangan ng mga ahs na paganahin para sa mga awtomatikong pag-update</fil_PH>
<fi>Liquorix ahs -päivityspaketti, vaatii ah:n olevan käytössä automaattisia päivityksiä varten</fi>
<fr>Package de mises à jour Liquorix ahs, nécessite que ahs soit activé pour les mises à jour automatiques</fr>
<he_IL>םייטמוטוא םינוכדע רובע ahs לש הלעפה תשרוד ,Liquorix ahs ינוכדע תליבח</he_IL>
<hi>लिकॉरिक्स एएचएस अपडेट पैकेज, स्वचालित अपडेट के लिए एएचएस को सक्षम करना आवश्यक है</hi>
<hr>Liquorix ahs paket ažuriranja, zahtijeva da ahs bude omogućen za automatska ažuriranja</hr>
<hu>A Liquorix ahs frissítőcsomagja, az automatikus frissítésekhez engedélyezni kell az ahs-t</hu>
<id>Paket pembaruan Liquorix ahs, mengharuskan ahs diaktifkan untuk pembaruan otomatis</id>
<is>Liquorix ahs uppfærslupakki, krefst þess að ahs sé virkt fyrir sjálfvirkar uppfærslur</is>
<it>Pacchetto aggiornamenti Liquorix ahs, richiede che ahs sia abilitato per gli aggiornamenti automatici</it>
<ja>Liquorix ahs アップデート パッケージ。自動アップデートするには ahs を有効にする必要があります</ja>
<kk>Liquorix ahs жаңарту бумасы, автоматты жаңартулар үшін ahs қосулы болуын талап етеді</kk>
<ko>Liquorix ahs 업데이트 패키지, 자동 업데이트를 위해 ahs 활성화 필요</ko>
<lt>„Liquorix ahs“ naujinimų paketas, norint automatiškai atnaujinti, reikia įjungti ahs</lt>
<mk>Пакетот за ажурирања на Liquorix ahs, бара овозможено ahs за автоматско ажурирање</mk>
<mr>Liquorix ahs पॅकेज अपडेट करते, स्वयंचलित अद्यतनांसाठी ahs सक्षम करणे आवश्यक आहे</mr>
<nb>Liquorix ahs oppdateringspakke, krever at ahs er aktivert for automatiske oppdateringer</nb>
<nl>Liquorix ahs-updatepakket, vereist dat ahs is ingeschakeld voor automatische updates</nl>
<pl>Pakiet aktualizacji Liquorix ahs, wymaga włączenia ahs do automatycznych aktualizacji</pl>
<pt_BR>Pacote de atualizações do Liquorix ahs, requer que o ahs esteja habilitado para atualizações automáticas</pt_BR>
<pt>Pacote de atualizações do Liquorix ahs, requer que o ahs esteja habilitado para atualizações automáticas</pt>
<ro>Pachetul de actualizări Liquorix ahs, necesită activarea ahs pentru actualizări automate</ro>
<ru>Пакет обновлений Liquorix ahs, для автоматического обновления требуется включить ahs.</ru>
<sk>Aktualizačný balík Liquorix ahs vyžaduje, aby bol ahs povolený pre automatické aktualizácie</sk>
<sl>Paket posodobitev Liquorix ahs, zahteva, da je ahs omogočen za samodejne posodobitve</sl>
<sq>Paketa e përditësimeve Liquorix ahs, kërkon që ahs të aktivizohet për përditësime automatike</sq>
<sr>Ликуорик ахс пакет ажурирања, захтева да ахс буде омогућен за аутоматска ажурирања</sr>
<sv>Liquorix ahs uppdateringspaket, kräver att ahs är aktiverat för automatiska uppdateringar</sv>
<tr>Liquorix ahs güncelleme paketi, otomatik güncellemeler için ahs'nin etkinleştirilmesini gerektirir</tr>
<uk>Пакет оновлень Liquorix ahs, вимагає ввімкнення ahs для автоматичних оновлень</uk>
<vi>Gói cập nhật Liquorix ahs, yêu cầu kích hoạt ahs để cập nhật tự động</vi>
</description>

<installable>
64
</installable>

<screenshot>none</screenshot>

<preinstall>
if [ $(apt-get update --print-uris | grep -c -m1 -E "/mx/repo/dists/bookworm/ahs/") = 0 ]; then
MXREPO=$(apt-get update --print-uris | grep -oE "https?://.*/mx/repo/dists/bookworm/main" | tail -1 | sed "s:^:deb :; s:/repo/dists/:/repo/ :; s:/main: ahs:")
: ${MXREPO:=deb http://mxrepo.com/mx/repo/ bookworm ahs}
echo "$MXREPO" > /etc/apt/sources.list.d/mxpitemp.list
apt-get update 
fi
DKMS_PKGS=($(dpkg-query -f '${db:Status-Abbrev}\t${Package}\n' -W  -- '*-dkms' | grep ^i | grep -- '-dkms$' | cut -d$'\t' -f2))
apt-get install linux-image-liquorix-amd64 linux-headers-liquorix-amd64 ${DKMS_PKGS[*]}
</preinstall>

<install_package_names>

</install_package_names>


<postinstall>
file=$(apt-cache show linux-image-liquorix-amd64 |grep -m1 Depends) 
file=${file#"Depends:"}
rebuild_dkms_packages.sh $file
if [ -f /etc/apt/sources.list.d/mxpitemp.list ]; then
rm /etc/apt/sources.list.d/mxpitemp.list
apt-get update
fi
echo "...$(gettext -d apt -s ' Done')!"
</postinstall>


<uninstall_package_names>
linux-image-liquorix-amd64
linux-headers-liquorix-amd64
</uninstall_package_names>
</app>
